summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/helloworld/plugin_helloworld.h
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/helloworld/plugin_helloworld.h')
-rw-r--r--kipi-plugins/helloworld/plugin_helloworld.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kipi-plugins/helloworld/plugin_helloworld.h b/kipi-plugins/helloworld/plugin_helloworld.h
index bf260da..c03ec39 100644
--- a/kipi-plugins/helloworld/plugin_helloworld.h
+++ b/kipi-plugins/helloworld/plugin_helloworld.h
@@ -36,10 +36,10 @@ class Plugin_HelloWorld : public KIPI::Plugin
public:
// Notice the constructor
// takes three arguments TQObject *tqparent (the tqparent of this object),
// const char* name (the name of this object) and
// const TQStringList &args (the arguments passed).
- Plugin_HelloWorld(TQObject *tqparent,
+ Plugin_HelloWorld(TQObject *parent,
const char* name,
const TQStringList &args);
@@ -36,10 +36,10 @@ class Plugin_HelloWorld : public KIPI::Plugin
public:
// Notice the constructor
- // takes three arguments TQObject *tqparent (the tqparent of this object),
+ // takes three arguments TQObject *parent (the parent of this object),
// const char* name (the name of this object) and
// const TQStringList &args (the arguments passed).